﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.VariableVector {
  [Item("UniformRandomVariableVectorCreator", "Description missing")]
  [StorableClass]
  public class UniformRandomVariableVectorCreator : VariableVectorCreator {

    #region Parameter Properties
    public ILookupParameter<PercentValue> ChangeSymbolProbabilityParameter {
      get { return (ILookupParameter<PercentValue>)Parameters["ChangeSymbolProbability"]; }
    }
    #endregion

    [StorableConstructor]
    protected UniformRandomVariableVectorCreator(bool deserializing) : base(deserializing) { }
    protected UniformRandomVariableVectorCreator(UniformRandomVariableVectorCreator original, Cloner cloner)
      : base(original, cloner) {
    }
    public UniformRandomVariableVectorCreator()
      : base() {
        Parameters.Add(new LookupParameter<PercentValue>("ChangeSymbolProbability"));
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new UniformRandomVariableVectorCreator(this, cloner);
    }

    protected override VariableVector Create(IRandom random, VariableVector sampleVariableVector, double spreadPercentage) {
      var result = sampleVariableVector.GetEmptyCopy();
      result.Randomize(random, ChangeSymbolProbabilityParameter.ActualValue.Value, spreadPercentage);
      return result;
    }
  }
}
